==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/TimeXAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TimeAxisBaseDescriptionMetadata } from "./TimeAxisBaseDescriptionMetadata";
import { TimeXAxisDescription } from "./TimeXAxisDescription";
/**
 * @hidden
 */
export let TimeXAxisDescriptionMetadata = /*@__PURE__*/ (() => {
    class TimeXAxisDescriptionMetadata extends Base {
        static b(a) {
            if (TimeXAxisDescriptionMetadata.a == null) {
                TimeXAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TimeXAxisDescriptionMetadata.c(TimeXAxisDescriptionMetadata.a);
            }
            if (a.j(TimeXAxisDescriptionMetadata.a)) {
                return;
            }
            a.y(TimeXAxisDescriptionMetadata.a);
        }
        static c(a) {
            TimeAxisBaseDescriptionMetadata.c(a);
            a.item("Breaks", "Collection:TimeAxisBreak:TimeAxisBreakCollection:TimeAxisBreak");
            a.item("LabellingMode", "ExportedType:string:TimeAxisLabellingMode");
            a.item("LabellingMode@names", "Auto;Normal;Compressed");
            a.item("LabelFormats", "Collection:TimeAxisLabelFormat:TimeAxisLabelFormatCollection:TimeAxisLabelFormat");
            a.item("Intervals", "Collection:TimeAxisInterval:TimeAxisIntervalCollection:TimeAxisInterval");
        }
        static d(a) {
            TimeXAxisDescriptionMetadata.b(a);
            a.aa("TimeXAxis", () => new TimeXAxisDescription());
            a.z("TimeXAxis", TimeXAxisDescriptionMetadata.a);
        }
    }
    TimeXAxisDescriptionMetadata.$t = /*@__PURE__*/ markType(TimeXAxisDescriptionMetadata, 'TimeXAxisDescriptionMetadata');
    TimeXAxisDescriptionMetadata.a = null;
    return TimeXAxisDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/TimeXAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TimeAxisBaseDescriptionMetadata } from "./TimeAxisBaseDescriptionMetadata";
import { TimeXAxisDescription } from "./TimeXAxisDescription";
/**
 * @hidden
 */
export let TimeXAxisDescriptionMetadata = /*@__PURE__*/ (() => {
    class TimeXAxisDescriptionMetadata extends Base {
        static b(a) {
            if (TimeXAxisDescriptionMetadata.a == null) {
                TimeXAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TimeXAxisDescriptionMetadata.c(TimeXAxisDescriptionMetadata.a);
            }
            if (a.k(TimeXAxisDescriptionMetadata.a)) {
                return;
            }
            a.aa(TimeXAxisDescriptionMetadata.a);
        }
        static c(a) {
            TimeAxisBaseDescriptionMetadata.c(a);
            a.item("Breaks", "Collection:TimeAxisBreak:TimeAxisBreakCollection:TimeAxisBreak");
            a.item("LabellingMode", "ExportedType:string:TimeAxisLabellingMode");
            a.item("LabellingMode@names", "Auto;Normal;Compressed");
            a.item("LabelFormats", "Collection:TimeAxisLabelFormat:TimeAxisLabelFormatCollection:TimeAxisLabelFormat");
            a.item("Intervals", "Collection:TimeAxisInterval:TimeAxisIntervalCollection:TimeAxisInterval");
        }
        static d(a) {
            TimeXAxisDescriptionMetadata.b(a);
            a.ac("TimeXAxis", () => new TimeXAxisDescription());
            a.ab("TimeXAxis", TimeXAxisDescriptionMetadata.a);
        }
    }
    TimeXAxisDescriptionMetadata.$t = /*@__PURE__*/ markType(TimeXAxisDescriptionMetadata, 'TimeXAxisDescriptionMetadata');
    TimeXAxisDescriptionMetadata.a = null;
    return TimeXAxisDescriptionMetadata;
})();
